@@ -1,6 +1,6 @@
 ;; guile-gnome
+;; Copyright (C) 2003,2004,2015 Andy Wingo <wingo at pobox dot com>
 ;; Copyright (C) 2001 Martin Baulig <martin@gnome.org>
-;;               2003,2004 Andy Wingo <wingo at pobox dot com>
 
 ;; This program is free software; you can redistribute it and/or    
 ;; modify it under the terms of the GNU General Public License as   
@@ -28,12 +28,11 @@
 (define-module (gnome corba types)
   :use-module (gnome gw corba)
   :use-module (gnome gobject)
-  :use-module (oop goops))
+  :use-module (oop goops)
+  :export (gnome-corba-error))
 
 (define (gnome-corba-error format-string . args)
-  (save-stack)
   (scm-error 'gnome-corba-error #f format-string args '()))
 
-(%init-gnome-corba-types)
-
-(export gnome-corba-error)
+(eval-when (load eval)
+  (%init-gnome-corba-types))
